@@ -5,12 +5,12 @@ if (getRversion() >= "3.1.0") {
 
 #' Find the number of layers in a Spatial Object
 #'
-#' There are already methods for \code{Raster*} in the raster package.
-#' Adding methods for \code{list}, \code{SpatialPolygons}, \code{SpatialLines},
-#' and \code{SpatialPoints}, \code{gg}, \code{histogram}, \code{igraph}.
-#' These latter classes return \code{1}.
+#' There are already methods for `Raster*` in the raster package.
+#' Adding methods for `list`, `SpatialPolygons`, `SpatialLines`,
+#' and `SpatialPoints`, `gg`, `histogram`, `igraph`.
+#' These latter classes return `1`.
 #'
-#' @param x A \code{.quickPlotObjects} object or list of these.
+#' @param x A `.quickPlotObjects` object or list of these.
 #'
 #' @return The number of layers in the object.
 #'
@@ -89,14 +89,14 @@ setMethod(
 
 #' Extract the layer names of Spatial Objects
 #'
-#' There are already methods for \code{Raster*} objects. This adds methods for
-#' \code{SpatialPoints*}, \code{SpatialLines*}, and \code{SpatialPolygons*},
+#' There are already methods for `Raster*` objects. This adds methods for
+#' `SpatialPoints*`, `SpatialLines*`, and `SpatialPolygons*`,
 #' returning an empty character vector of length 1.
 #' This function was created to give consistent, meaningful results for all
-#' classes of objects plotted by \code{Plot}.
+#' classes of objects plotted by `Plot`.
 #'
-#' @param object  A \code{Raster*}, \code{SpatialPoints*}, \code{SpatialLines*},
-#'                or \code{SpatialPolygons*} object; or list of these.
+#' @param object  A `Raster*`, `SpatialPoints*`, `SpatialLines*`,
+#'                or `SpatialPolygons*` object; or list of these.
 #'
 #' @author Eliot McIntire
 #' @export
@@ -230,23 +230,23 @@ setMethod(
     )
 })
 
-#' Make a \code{.quickPlot} class object
+#' Make a `.quickPlot` class object
 #'
-#' Builds a \code{.quickPlot} object from a list of objects.
+#' Builds a `.quickPlot` object from a list of objects.
 #'
 #' @param plotObjects list. Any plot objects.
 #'
 #' @param plotArgs list. Any arguments that the the grid package can accept for
-#' the specific grob types, e.g., rasterGrob, polygonGrob, etc.
+#' the specific grob types, e.g., `rasterGrob`, `polygonGrob`, etc.
 #'
 #' @param whichQuickPlottables  Logical indicating which objects in the
-#' \code{Plot} call can be plotted by \code{Plot}.
+#' `Plot` call can be plotted by `Plot`.
 #'
 #' @param ... additional arguments. Currently nothing.
 #'
-#' @return A \code{\link{.quickPlot}} object, which has 2 slots, one for the plot arrangement
-#' (i.e., layout and dimensions) and one for all of the \code{quickPlotGrobs}
-#' (stored as a quickPlotGrobList of lists \code{.quickPlotGrob} objects).
+#' @return A [.quickPlot()] object, which has 2 slots, one for the plot arrangement
+#' (i.e., layout and dimensions) and one for all of the `quickPlotGrobs`
+#' (stored as a `quickPlotGrobList` of lists `.quickPlotGrob` objects).
 #'
 #' @author Eliot McIntire
 #' @export
@@ -393,16 +393,16 @@ setMethod(
     return(newPlots)
 })
 
-#' Convert \code{plotArgs} to list of lists
+#' Convert `plotArgs` to list of lists
 #'
-#' Internal function. Take the inputs as plotArgs to the Plot function, and make
-#' them a list of length \code{numQuickPlotObjects} entries of lists.
+#' Internal function. Take the inputs as `plotArgs` to the Plot function, and make
+#' them a list of length `numQuickPlotObjects` entries of lists.
 #'
 #' @inheritParams .makeQuickPlot
 #'
-#' @param numQuickPlotObjects Numeric. The number of \code{.quickPlotObjects}.
-#'                 This can't easily be deduced from the \code{plotArgs} because
-#'                 of the \code{RasterStack}s. So passed manually.
+#' @param numQuickPlotObjects Numeric. The number of `.quickPlotObjects`.
+#'                 This can't easily be deduced from the `plotArgs` because
+#'                 of the `RasterStack`s. So passed manually.
 #'
 #' @author Eliot McIntire
 #' @include plotting-classes.R
@@ -634,17 +634,17 @@ setMethod(
     return(p)
 })
 
-#' Make \code{SpatialLines} object from two \code{SpatialPoints} objects
+#' Make `SpatialLines` object from two `SpatialPoints` objects
 #'
 #' The primary conceived usage of this is to draw arrows following the
 #' trajectories of agents.
 #'
-#' @param from  Starting spatial coordinates (\code{SpatialPointsDataFrame}).
+#' @param from  Starting spatial coordinates (`SpatialPointsDataFrame`).
 #'
-#' @param to    Ending spatial coordinates (\code{SpatialPointsDataFrame}).
+#' @param to    Ending spatial coordinates (`SpatialPointsDataFrame`).
 #'
-#' @return A \code{SpatialLines} object. When this object is used within a
-#'         \code{Plot} call and the \code{length} argument is specified, then
+#' @return A `SpatialLines` object. When this object is used within a
+#'         `Plot` call and the `length` argument is specified, then
 #'         arrow heads will be drawn. See examples.
 #'
 #' @author Eliot McIntire
@@ -675,26 +675,23 @@ setMethod(
 
 #' Parse arguments and find environments
 #'
-#' Internal function used within objectNames.
+#' Internal function used within `objectNames`.
 #'
-#' @param y  A character representation of the arguments passed to a function,
-#'           e.g., \code{Plot}.
+#' @param y  A character representation of the arguments passed to a function, e.g., `Plot`.
 #'
-#' @param e  Environment in which the function (e.g., \code{Plot}) was called.
+#' @param e  Environment in which the function (e.g., `Plot`) was called.
 #'
-#' @param eminus1  The parent environment of \code{e}.
+#' @param eminus1  The parent environment of `e`.
 #'
-#' @return A list of length 2, with names \code{objs} and \code{envs} giving the
-#' standardized representation (i.e., replacing \code{[[]]} with \code{$}
-#' notation for objects) of objects and their layers (if \code{RasterStacks}).
+#' @return A list of length 2, with names `objs` and `envs` giving the
+#' standardized representation (i.e., replacing `[[]]` with `$` notation for objects) of objects
+#' and their layers (if `RasterStack`s).
 #'
+#' @author Eliot McIntire and Alex Chubaty
 #' @importFrom grDevices dev.cur
 #' @include plotting-classes.R
 #' @keywords internal
 #' @rdname parseArgs
-#' @author Eliot McIntire and Alex Chubaty
-#'
-# igraph exports %>% from magrittr
 .parseArgs <- function(y, e, eminus1) {
   elems <- list()
   i <- 1
@@ -881,20 +878,20 @@ setMethod(
 ################################################################################
 #' Extracts the object names
 #'
-#' Internal function primarily used from \code{Plot}.
+#' Internal function primarily used from `Plot`.
 #'
 #' @param calledFrom  character vector of length 1, indicating which function
-#'                    call is desired. Defaults to \code{Plot}.
+#'                    call is desired. Defaults to `Plot`.
 #'
 #' @param argClass    character vector of length 1, indicating which class is
 #'                    being searched for among the arguments.
-#'                    Defaults to \code{.quickPlotObjects}.
+#'                    Defaults to `.quickPlotObjects`.
 #'
-#' @param argName     character vector of length 1, or \code{NULL}, indicating
+#' @param argName     character vector of length 1, or `NULL`, indicating
 #'                    if the arguments to select have a name, no name (empty
-#'                    string), or do not use name (\code{NULL}).
+#'                    string), or do not use name (`NULL`).
 #'
-#' @return \code{NULL}. This function is invoked for its side effects.
+#' @return `NULL`. This function is invoked for its side effects.
 #'
 #' @author Eliot McIntire
 #' @export
@@ -923,8 +920,8 @@ setMethod(
 
 #' Importing some grid functions
 #'
-#' Currently only the gpar function is imported. This is a convenience so that users
-#' can change \code{Plot} arguments without having to load the entire grid package.
+#' Currently only the `gpar` function is imported. This is a convenience so that users
+#' can change `Plot` arguments without having to load the entire grid package.
 #'
 #' @inheritParams grid::gpar
 #'
@@ -933,7 +930,7 @@ setMethod(
 #' @importFrom grid gpar
 #' @name gpar
 #' @rdname grid-functions
-#' @seealso \code{\link[grid]{gpar}}
+#' @seealso [grid::gpar()]
 #'
 setGeneric("gpar", function(...) {
   standardGeneric("gpar")
@@ -946,19 +943,19 @@ setMethod("gpar",
             return(grid::gpar(...))
 })
 
-#' Internal functions used by Plot
+#' Internal functions used by `Plot`
 #'
-#' Extract colors, legends and other things from object, and convert to a plotGrob
+#' Extract colours, legends and other things from object, and convert to a `plotGrob`.
 #'
 #' @param grobToPlot Graphical object to plot
-#' @param sGrob quickPlotGrob object
-#' @param takeFromPlotObj Logical indicating whether data for grobToPlot should be found in
+#' @param sGrob `quickPlotGrob` object
+#' @param takeFromPlotObj Logical indicating whether data for `grobToPlot` should be found in
 #'        current call to Plot or from disk
 #' @param arr An arrangement object
 #' @param newArr Logical, whether there is a new arrangement happening
-#' @param quickPlotGrobCounter Numeric. A counter. No meaning outside Plot function.
+#' @param quickPlotGrobCounter Numeric. A counter. No meaning outside `Plot` function.
 #' @param subPlots Character. Name of plot area.
-#' @param cols Color vector.
+#' @param cols Colour vector.
 #'
 #' @aliases PlotHelpers
 #' @author Eliot McIntire
@@ -968,7 +965,7 @@ setMethod("gpar",
 #' @rdname Plot-internal
 #'
 setGeneric(".preparePlotGrob", function(grobToPlot, sGrob, takeFromPlotObj, arr, newArr,
-                                                 quickPlotGrobCounter, subPlots, cols)
+                                        quickPlotGrobCounter, subPlots, cols)
   standardGeneric(".preparePlotGrob")
 )
 
@@ -1037,7 +1034,7 @@ setMethod(
 
     }
 
-    # This handles SpatialPointsDataFrames with column "color"
+    # This handles SpatialPointsDataFrames with column "colour"
     if (any(grepl(pattern = "color", names(grobToPlot))) & is.null(cols))
       sGrob@plotArgs$cols <- unlist(getColors(grobToPlot))
 
@@ -1071,7 +1068,7 @@ setMethod(
   return(zMat)
 })
 
-#' @param whPlotFrame Numeric. Which plot within the quickPlotGrobPlots object.
+#' @param whPlotFrame Numeric. Which plot within the `quickPlotGrobPlots` object.
 #'
 #' @include plotting-classes.R
 #' @aliases PlotHelpers
@@ -1130,19 +1127,19 @@ setMethod(
     return(list(x = xaxis, y = yaxis))
 })
 
-#' @param quickSubPlots List of many quickPlotGrobs
+#' @param quickSubPlots List of many `quickPlotGrobs`
 #' @param isBaseSubPlot Logical. Is the currently being plotted object a base layer
 #' @param isNewPlot Logical. Is the currently being plotted object a new, additional plot
 #' @param isReplot Logical. Is the currently being plotted object a replot due to something
 #'                 like a rearrangement
-#' @param zMat List resulting from \code{.preparePlotGrob}
+#' @param zMat List resulting from `.preparePlotGrob`
 #' @param wipe Logical. Is the currently being plotted object require a white rectangle to
 #'             be plotted first, and subsequent other changes.
-#' @param xyAxes List of length 2, resulting from \code{.xyAxes}
+#' @param xyAxes List of length 2, resulting from `.xyAxes`
 #' @inheritParams Plot
-#' @param vps A viewport tree resulting from \code{.makeViewports}
-#' @param nonPlotArgs Arguments passed to \code{Plot} that are not \code{.quickPlottables},
-#'                    but are passed along with \code{.quickPlottables}.
+#' @param vps A viewport tree resulting from `.makeViewports`
+#' @param nonPlotArgs Arguments passed to `Plot` that are not `.quickPlottables`,
+#'                    but are passed along with `.quickPlottables`.
 #'
 #' @include plotting-classes.R
 #' @importFrom grid seekViewport grid.text
@@ -1358,7 +1355,7 @@ setMethod(
 #' @param nColumns Numeric, length 1, indicating how many columns are in the device arrangement
 #' @param nRows Numeric, length 1, indicating how many rows are in the device arrangement
 #' @param whPlotObj Numeric. Length 1, indicating which of the currently objects passed into
-#'                  \code{Plot} is currently being plotted, i.e., a counter of sorts.
+#'                  `Plot` is currently being plotted, i.e., a counter of sorts.
 #'
 #' @include plotting-classes.R
 #' @inheritParams .makeQuickPlot
@@ -1453,17 +1450,15 @@ setMethod(
 #'
 #' Internal function.
 #'
-#' Because the Plot function can use the global environment as a source of
-#' objects to plot, not just the call itself, this function identifies where
-#' the data for the grob should come from, the current call or the global
-#' environment.
+#' Because the `Plot` function can use the global environment as a source of
+#' objects to plot, not just the call itself, this function identifies where the
+#' data for the grob should come from, the current call or the global environment.
 #'
 #' @param toPlot The object to plot. Should be a single layer if from a multi-layer
-#'               object such as a RasterStack.
-#' @param sGrob quickPlot grob object
+#'               object such as a `RasterStack`.
+#' @param sGrob `quickPlot` grob object
 #' @param takeFromPlotObj Logical. Should the data come from the argument passed
-#'                        into Plot (\code{TRUE}), or from the (\code{.quickPlotEnv})
-#'                        (\code{FALSE}).
+#'                        into `Plot` (`TRUE`), or from the (`.quickPlotEnv`) (`FALSE`).
 #'
 #' @author Eliot McIntire
 #' @include plotting-classes.R
@@ -1508,19 +1503,20 @@ setMethod(
 
 #' Prepare raster for plotting
 #'
-#' Internal function. Takes a raster .quickPlotGrob, and converts zoomExtent into
-#' a zoom, and legendRange into a legend.
-#' Then calculates the maxpixels to plot for speed.
+#' Internal function. Takes a raster `.quickPlotGrob`, and converts `zoomExtent` into
+#' a zoom, and `legendRange` into a legend.
+#' Then calculates the `maxpixels` to plot for speed.
 #'
-#' @param grobToPlot .quickPlotGrob
+#' @param grobToPlot A `.quickPlotGrob` object.
 #'
 #' @param zoomExtent an extent object
 #'
 #' @param legendRange a numeric vector of length >=2 indicating the desired legend range.
 #'
-#' @param takeFromPlotObj logical. Should the object be found in the Plot call or .GlobalEnv
+#' @param takeFromPlotObj logical. Should the object be found in the `Plot` call or
+#'   `.GlobalEnv`
 #'
-#' @param arr an \code{.arrangement} object
+#' @param arr an `.arrangement` object
 #'
 #' @param speedup numeric, greater than 1 will usually speed up plotting at the
 #'                expense of resolution
@@ -1565,12 +1561,12 @@ setMethod(
 
 #' Merge two quickPlot objects
 #'
-#' Merges two \code{.quickPlot} objects
+#' Merges two `.quickPlot` objects
 #'
-#' @param newSP  The "new" \code{.quickPlot} object.
+#' @param newSP  The "new" `.quickPlot` object.
 #'               I.e., the new merges and overwrites into current.
 #'
-#' @param curr   The "current" \code{.quickPlot} object.
+#' @param curr   The "current" `.quickPlot` object.
 #'               I.e., the one to be merged into.
 #'
 #' @param ...    Additional arguments. Currently none implemented.
@@ -1720,7 +1716,7 @@ setMethod(
 #' number of spatial objects to plot and builds an object that will be used by
 #' the Plot functions to plot them efficiently.
 #'
-#' @param sPlot A \code{.quickPlot} object.
+#' @param sPlot A `.quickPlot` object.
 #' @inheritParams Plot
 #'
 #' @author Eliot McIntire
@@ -1801,66 +1797,65 @@ setMethod(
 #'
 #' Internal function. Plot a raster Grob, a points Grob, polygon Grob.
 #'
-#' \code{speedup} is only used for \code{SpatialPolygons}, \code{SpatialPoints},
-#' and \code{SpatialLines} in this function.
+#' `speedup` is only used for `SpatialPolygons`, `SpatialPoints`,
+#' and `SpatialLines` in this function.
 #' Attempts have been made to subsample at a good level that optimizes speed of
 #' plotting, without losing visible quality. Nevertheless, to force all points to
 #' be plotted, use a speedup value less than 0.1.
 #' From a speed perspective, there appears to be an optimal subsampling when
-#' using \code{thin} from the \pkg{fastshp} package.
+#' using `thin` from the \pkg{fastshp} package.
 #' Presumably, too much thinning requires large distance matrices to be
 #' calculated, slowing plotting down.
 #' Too little thinning causes an overabundance of points to be plotted, slowing
 #' plotting down.
 #'
-#' The suggested package \code{fastshp} can be installed with:
-#' \code{install.packages("fastshp", repos = "https://rforge.net", type = "source")}.
+#' The suggested package `fastshp` can be installed with:
+#' `install.packages("fastshp", repos = "https://rforge.net", type = "source")`.
 #'
 #' NOTE: you may get errors relating to not having installed the software tools
 #' required for building R packages on your system.
-#' For building on Windows, you'll need to install \code{Rtools} from
-#' \url{https://cran.r-project.org/bin/windows/Rtools/}.
+#' For building on Windows, you'll need to install `Rtools` from
+#' <https://cran.r-project.org/bin/windows/Rtools/>.
 #'
-#' @param grobToPlot  \code{Raster*}, \code{SpatialLines*},
-#'                    \code{SpatialPoints*}, or \code{SpatialPolygons*} object.
+#' @param grobToPlot  `Raster*`, `SpatialLines*`,
+#'                    `SpatialPoints*`, or `SpatialPolygons*` object.
 #'
-#' @param col     Currently only used for the legend of a \code{Raster*} object.
+#' @param col     Currently only used for the legend of a `Raster*` object.
 #'
-#' @param size    The size of the \code{SpatialPoints}.
+#' @param size    The size of the `SpatialPoints`.
 #'
-#' @param gp      \code{grid} parameters, usually the output of a call to
-#'                \code{\link{gpar}}.
+#' @param gp      `grid` parameters, usually the output of a call to [gpar()].
 #'
-#' @param gpText  \code{gpar} object for legend label text.
+#' @param gpText  `gpar` object for legend label text.
 #'
 #' @param legend  Logical indicating whether a legend should be drawn.
-#'                Default \code{TRUE}.
+#'                Default `TRUE`.
 #'
 #' @param legendText  Vector of values to use for legend value labels.
-#'                    Defaults to \code{NULL} which results in a pretty numeric
-#'                    representation. If \code{Raster*} has a Raster Attribute
+#'                    Defaults to `NULL` which results in a pretty numeric
+#'                    representation. If `Raster*` has a Raster Attribute
 #'                    Table (rat; see \pkg{raster} package), this will be used
 #'                    by default. Currently, only a single vector is accepted.
 #'
 #' @param length  Numeric.
 #'
-#' @param minv    The minimum value on a \code{Raster*}. Required because not
+#' @param minv    The minimum value on a `Raster*`. Required because not
 #'                all Rasters have this defined internally.
 #'
-#' @param maxv    The maximum value on a \code{Raster*}. Required because not
+#' @param maxv    The maximum value on a `Raster*`. Required because not
 #'                all Rasters have this defined internally.
 #'
-#' @param pch     Point character for \code{SpatialPoints}, as \code{par}.
+#' @param pch     Point character for `SpatialPoints`, as `par`.
 #'
-#' @param real    Logical indicating whether the data are \code{real} numbers
-#'                (i.e., as opposed to \code{integer} or \code{factor}).
+#' @param real    Logical indicating whether the data are `real` numbers
+#'                (i.e., as opposed to `integer` or `factor`).
 #'
 #' @param speedup Numeric. The factor by which the number of vertices in
-#'                \code{SpatialPolygons} and \code{SpatialLines*} will be
+#'                `SpatialPolygons` and `SpatialLines*` will be
 #'                subsampled. The vertices are already subsampled by default to
 #'                make plotting faster.
 #'
-#' @param vp      whole viewport tree of \code{quickPlotGrob}
+#' @param vp      whole viewport tree of `quickPlotGrob`
 #'
 #' @param name    Character string of name of object being plotted.
 #'
@@ -2086,14 +2081,52 @@ setMethod(
           xmax(extent(grobToPlot)) - xmin(extent(grobToPlot))) / 2.4e4
     }
 
-    if (is.null(gp$fill)) {
-      gp$fill <- rep(RColorBrewer::brewer.pal(8, "Set2"), length.out = length(grobToPlot))
-    }
-
     # For speed of plotting
     xyOrd <- quickPlot::thin(grobToPlot, tolerance = speedupScale * speedup,
                              returnDataFrame = TRUE, minCoordsToThin = 1e5, ...)
 
+    numPolys <- length(unique(xyOrd$xyOrd$poly))
+    numSubPolys <- length(unique(xyOrd$xyOrd$groups))
+    if (!is.null(col)) {
+      gp$fill <- col
+    }
+    theCols <- if ((length(gp$fill) == 1 && gp$fill %in% rownames(RColorBrewer::brewer.pal.info)) ||
+                   is.null(gp$fill)) {
+      if (is.null(gp$fill)) {
+        pal <- "Set2"
+      } else {
+        pal <- gp$fill
+      }
+      if (pal %in% rownames(RColorBrewer::brewer.pal.info)) {
+        numCols <- RColorBrewer::brewer.pal.info[pal,"maxcolors"]
+      }
+      rep(RColorBrewer::brewer.pal(numCols, pal), length.out = numPolys)
+    } else {
+      if (length(gp$fill) < numPolys) {
+        message("not enough colours for each polygon (there are ",numPolys,"), recycling")
+        rep(gp$fill, length.out = numPolys)
+      } else if (length(gp$fill) > numPolys) {
+        message("more colours than number of polygons (there are ",numPolys,"), setting unique colors to sub-polygons (there are "
+                ,numSubPolys,")")
+        if (length(gp$fill) != numSubPolys) {
+          message("Incorrect number of colours for number of sub-polygons; recycling")
+        }
+        rep(gp$fill, length.out = numSubPolys)
+      } else {
+        gp$fill
+      }
+    }
+
+    if (length(gp$fill) <= numPolys) {
+      dtFill <- data.table(poly = seq(numPolys),
+                           col = theCols)
+      dtFill2 <- unique(xyOrd$xyOrd[, c("groups", "poly")])
+      dtFill2 <- dtFill[dtFill2, on = "poly"]
+      gp$fill <- dtFill2$col
+    } else if (length(gp$fill) < NROW(xyOrd$idLength)) {
+      gp$fill <- theCols
+    }
+
     polyGrob <- .createPolygonGrob(gp = gp, xyOrd = xyOrd)
     grid.draw(polyGrob, recording = FALSE)
     return(invisible(polyGrob))
@@ -2191,20 +2224,20 @@ setMethod(
 #' Internal function. Using the size of the current device, and number and
 #' dimension ratios of the plots, place them optimally in the plotting region.
 #'
-#' @param arr an object of class \code{.arrangement}.
+#' @param arr an object of class `.arrangement`.
 #'
 #' @param visualSqueeze Numeric. The proportion of the white space to be used
 #'                      for plots. Default is 0.75.
 #'
 #' @param legend Logical indicating whether legend should be included as part of
-#'               layout calculation. Default is \code{TRUE}.
+#'               layout calculation. Default is `TRUE`.
 #'
 #' @param axes Logical indicating whether the axes should be included as part of
-#'             layout calculation. Default is \code{TRUE}.
+#'             layout calculation. Default is `TRUE`.
 #'
 #' @param title Logical indicating whether the names of each plot should be
 #'              written above plots and should be included as part of layout
-#'               calculation. Default is \code{TRUE}.
+#'               calculation. Default is `TRUE`.
 #'
 #' @author Eliot McIntire
 #' @importFrom grid unit unit.c
@@ -2260,10 +2293,10 @@ setMethod(
 #' add some nested viewports to an existing arrangement, i.e., is there still
 #' white space available to plot.
 #'
-#' @param sPlot An object of class \code{.quickPlot}.
+#' @param sPlot An object of class `.quickPlot`.
 #'
 #' @param newArr  Logical indicating whether this function will create a
-#'                completely new viewport. Default \code{FALSE}.
+#'                completely new viewport. Default `FALSE`.
 #'
 #' @author Eliot McIntire
 #' @include plotting-classes.R
@@ -2381,12 +2414,12 @@ setMethod(
   return(list(wholeVp = wholeVp, extents = extents))
 }
 
-#' Test whether class has bbox method
+#' Test whether class has `bbox` method
 #'
 #' For internal use only.
 #'
 #' @rdname hasBbox
-#' @param z Logical, whether this object is a SpatialObject
+#' @param z Logical, whether this object is a `SpatialObject`
 #' @param objClass The class of the object
 #' @param objName The character string name of the object
 #' @param objEnv The environment where the object can be found
@@ -2411,22 +2444,21 @@ setMethod(
   }
 }
 
-#' Convert pairs of coordinates to SpatialLines
+#' Convert pairs of coordinates to `SpatialLines`
 #'
-#' This will convert 2 objects whose coordinates can be extracted with \code{coordinates}
-#' (e.g., \code{sp::SpatialPoints*})
-#' to a single SpatialLines
-#' object. The first object is treated as the "to" or destination, and the
-#' second object the "from" or source. This can be used to represent
-#' directional SpatialLines, especially with with arrow heads, as in
-#' \code{Plot(sl, length = 0.1)}
+#' This will convert 2 objects whose coordinates can be extracted with `coordinates`
+#' (e.g., `sp::SpatialPoints*`) to a single `SpatialLines` object.
+#' The first object is treated as the "to" (destination), and the second object the "from" (source).
+#' This can be used to represent directional `SpatialLines`, especially with with arrow heads,
+#' as in `Plot(sl, length = 0.1)`.
+#'
+#' @param sp1 a `SpatialPoints*` object
+#' @param from a `SpatialPoints*` object. Optional. If not provided, then the function will
+#'             attempt to find the "previous" coordinates as columns (`prevX`, `prevY`)
+#'             in the `sp1` object.
 #'
 #' @export
-#' @importFrom sp SpatialLines Lines Line coordinates
-#' @param sp1 SpatialPoints* object
-#' @param from SpatialPoints* object. Optional. If not provided, then the function
-#'             will attempt to find the "previous" coordinates as columns
-#'             (\code{prevX}, \code{prevY}) in the \code{sp1} object.
+#' @importFrom sp coordinates Line Lines SpatialLines
 #' @examples
 #' caribou <- sp::SpatialPoints(coords = cbind(x = stats::runif(1e1, -50, 50),
 #'                                         y = stats::runif(1e1, -50, 50)))
@@ -2450,31 +2482,30 @@ sp2sl <- function(sp1, from) {
   SpatialLines(l)
 }
 
-#' Thin a polygon using \code{fastshp::thin}
+#' Thin a polygon using `fastshp::thin`
 #'
-#' For visualizing, it is sometimes useful to remove points in Spatial* objects.
+#' For visualizing, it is sometimes useful to remove points in `Spatial*` objects.
 #' This will change the geometry, so it is not recommended for computation.
-#' This is similar to \code{rgeos::gSimplify} and \code{sf::st_simplify},
+#' This is similar to `rgeos::gSimplify` and `sf::st_simplify`,
 #' but faster than both (see examples) for large shapefiles, particularly if
-#' \code{returnDataFrame} is \code{TRUE}.
-#' \emph{\code{thin} will not attempt to preserve topology.}
-#' It is strictly for making smaller polygons for the purpose (likely)
-#' of visualizing more quickly.
+#' `returnDataFrame` is `TRUE`.
+#' *`thin` will not attempt to preserve topology.*
+#' It is strictly for making smaller polygons for the (likely) purpose of visualizing more quickly.
 #'
-#' @param x A Spatial* object
+#' @param x A `Spatial*` object
 #' @param tolerance Maximum allowable distance for a point to be removed.
-#' @param returnDataFrame If \code{TRUE}, this will return a list of 3 elements,
-#'        \code{xyOrd}, \code{hole}, and \code{idLength}.
-#'        If \code{FALSE} (default), it will return a \code{SpatialPolygons} object.
+#' @param returnDataFrame If `TRUE`, this will return a list of 3 elements,
+#'        `xyOrd`, `hole`, and `idLength`.
+#'        If `FALSE` (default), it will return a `SpatialPolygons` object.
 #' @param minCoordsToThin If the number of coordinates is smaller than this number,
 #'        then thin will just pass through, though it will take the time required to
-#'        calculate how many points there are (which is not NROW(coordinates(x)) for
-#'        a SpatialPolygon)
-#' @param ... Passed to methods (e.g., \code{maxNumPolygons})
-#' @param maxNumPolygons For speed, \code{thin} can also simply remove some of the
+#'        calculate how many points there are (which is not `NROW(coordinates(x))` for
+#'        a `SpatialPolygon`)
+#' @param ... Passed to methods (e.g., `maxNumPolygons`)
+#' @param maxNumPolygons For speed, `thin` can also simply remove some of the
 #'        polygons. This is likely only a reasonable thing to do if there are
 #'        a lot of polygons being plotted in a small space. Current default is
-#'        taken from \code{options('quickPlot.maxNumPolygons')}, with a message.
+#'        taken from `options('quickPlot.maxNumPolygons')`, with a message.
 #'
 #' @export
 #' @importFrom data.table as.data.table data.table set
@@ -2672,9 +2703,11 @@ thin.default <- function(x, tolerance, returnDataFrame, minCoordsToThin, ...) {
   message("No method for that class of object exists. See methods('thin') to see current methods")
 }
 
-#' Fortify - i.e,. convert an arbitrary object to a data.frame-like object
+#' Fortify
 #'
-#' This only deals with SpatialPolygons.
+#' Convert an arbitrary object to a `data.frame`-like object.
+#'
+#' @note This only deals with `SpatialPolygons` objects.
 #'
 #' @rdname fortify
 #' @name fortify
@@ -2719,6 +2752,10 @@ thin.default <- function(x, tolerance, returnDataFrame, minCoordsToThin, ...) {
     lapply(i, length)
   })) / 2)
 
+  polyLength <- data.table(V1 = unlist(lapply(xyOrd.l, function(i) {
+    NROW(i)
+  })))
+
   numPolygons <- unlist(length(xyOrd.l))
   numPolygon <- unlist(lapply(xyOrd.l, length))
 
@@ -2727,6 +2764,9 @@ thin.default <- function(x, tolerance, returnDataFrame, minCoordsToThin, ...) {
   }))
 
   groups <- rep(1:NROW(idLength), idLength$V1)
+  poly <- rep(1:NROW(polyLength), polyLength$V1)
+  poly <- rep(poly, idLength$V1)
+
   if (!simple | matchFortify) {
     # Polygons <- rep(rep(seq(numPolygons), numPolygon), idLength$V1) # sequential numbering
     Polygons <- rep(rep(IDs, numPolygon), idLength$V1) # actual ID labelling
@@ -2742,7 +2782,7 @@ thin.default <- function(x, tolerance, returnDataFrame, minCoordsToThin, ...) {
                       #group = paste0(as.character(Polygons), ".", as.character(Polygon)))) # the actual fortify
                       group = groups))
   } else {
-    out <- setDT(data.frame(x = xyOrd[,1], y = xyOrd[,2], groups = groups))
+    out <- setDT(data.frame(x = xyOrd[,1], y = xyOrd[,2], groups = groups, poly = poly))
     if (!simple) {
       set(out, , "order", orders)
       set(out, , "hole", holes)
@@ -2757,11 +2797,10 @@ thin.default <- function(x, tolerance, returnDataFrame, minCoordsToThin, ...) {
 
 .polygonSeq <- function(polygon, maxNumPolygons) {
   if (is.numeric(polygon@data$Shape_Area)) {
-    which(polygon@data$Shape_Area>(sort(polygon@data$Shape_Area, decreasing = TRUE)[maxNumPolygons]))
+    which(polygon@data$Shape_Area > (sort(polygon@data$Shape_Area, decreasing = TRUE)[maxNumPolygons]))
   } else {
     round(seq(1, length(polygon), length.out = maxNumPolygons))
   }
-
 }
 
 .createPolygonGrob <- function(gp, xyOrd) {
@@ -2775,11 +2814,9 @@ thin.default <- function(x, tolerance, returnDataFrame, minCoordsToThin, ...) {
   ),
   gp = gp,
   cl = "plotPoly")
-
 }
 
 .showingOnlyMessage <- function(numShowing, totalAvailable) {
   message("Showing only ", numShowing, " of ",
           totalAvailable," polygons in this view. See options('quickPlot.maxNumPolygons')")
-
 }
